# Generated by Django 2.2.6 on 2020-04-04 07:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('registry', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='entry',
            name='type',
            field=models.CharField(blank=True, choices=[('str', 'string'), ('int', 'integer'), ('float', 'float'), ('bool', 'bool')], default='str', max_length=8, verbose_name='Type'),
        ),
    ]
